Change in osmo-bsc[master]: abis_rsl.c: make sure emergency calls are rejected early

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

laforge gerrit-no-reply at lists.osmocom.org
Wed Aug 12 19:02:11 UTC 2020


laforge has submitted this change. ( https://gerrit.osmocom.org/c/osmo-bsc/+/19580 )

Change subject: abis_rsl.c: make sure emergency calls are rejected early
......................................................................

abis_rsl.c: make sure emergency calls are rejected early

If a CHAN RQD indicates an emergency call on a BTS that does not allow
emergency calls, then respond with an IMMEDIAGE ASSIGNMENT REJECT
message to deny the emergency call early.

Related: OS#4548
Change-Id: I148c540269bffd703f38233a1e689e863c175e97
---
M src/osmo-bsc/abis_rsl.c
1 file changed, 10 insertions(+), 1 deletion(-)

Approvals:
  fixeria: Looks good to me, approved
  Jenkins Builder: Verified



diff --git a/src/osmo-bsc/abis_rsl.c b/src/osmo-bsc/abis_rsl.c
index 1ffdd06..6787511 100644
--- a/src/osmo-bsc/abis_rsl.c
+++ b/src/osmo-bsc/abis_rsl.c
@@ -1394,11 +1394,20 @@
 
 	/* check availability / allocate channel
 	 *
 	 * - First try to allocate SDCCH.
 	 * - If SDCCH is not available, try a TCH/H (less bandwidth).
 	 * - If there is still no channel available, try a TCH/F.
 	 *
 	 */
+	if (chreq_reason == GSM_CHREQ_REASON_EMERG) {
+		if (bts->si_common.rach_control.t2 & 0x4) {
+			LOG_BTS(bts, DRSL, LOGL_NOTICE, "CHAN RQD: MS attempts EMERGENCY CALL although EMERGENCY CALLS "
+				"are not allowed in sysinfo (spec violation by MS!)\n");
+			rsl_tx_imm_ass_rej(bts, rqd_ref);
+			return -EINVAL;
+		}
+	}
 	lchan = lchan_select_by_type(bts, GSM_LCHAN_SDCCH);
 	if (!lchan) {
 		LOG_BTS(bts, DRSL, LOGL_NOTICE, "CHAN RQD: no resources for %s 0x%x, retrying with %s\n",
@@ -1394,11 +1394,20 @@
 	/* check availability / allocate channel
 	 *
-	 * - First try to allocate SDCCH.
+	 * - First check for EMERGENCY call attempts,
+	 * - then try to allocate SDCCH.
 	 * - If SDCCH is not available, try a TCH/H (less bandwidth).
 	 * - If there is still no channel available, try a TCH/F.

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/19580
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I148c540269bffd703f38233a1e689e863c175e97
Gerrit-Change-Number: 19580
Gerrit-PatchSet: 5
Gerrit-Owner: dexter <pmaier at sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy at sysmocom.de>
Gerrit-Reviewer: laforge <laforge at osmocom.org>
Gerrit-MessageType: merged
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20200812/4b320d23/attachment.htm>


More information about the gerrit-log mailing list